Gaussian

Struct Gaussian 

pub struct Gaussian {
    pub rot: Quat,
    pub pos: Vec3,
    pub color: U8Vec4,
    pub sh: [Vec3; 15],
    pub scale: Vec3,
}
The Gaussian.

This is an intermediate representation used by the CPU to convert to GaussianPod.

Fields

rot: Quatpos: Vec3color: U8Vec4sh: [Vec3; 15]scale: Vec3

Implementations

Source

impl Gaussian

pub const SH0_TO_LINEAR_FACTOR: f32 = 0.282094806f32

The constant to convert from SH coefficient at degree 0 to linear color.

pub const SPZ_SH0_TO_LINEAR_FACTOR: f32 = 0.150000006f32

The constant to convert from SH coefficient at degree 0 to linear color in SPZ.

pub fn from_ply(ply: &PlyGaussianPod) -> Self

Convert from PlyGaussianPod.

pub fn to_ply(&self) -> PlyGaussianPod

Convert to PlyGaussianPod.

pub fn from_spz(spz: SpzGaussianRef<'_>, header: &SpzGaussiansHeader) -> Self

Convert from SpzGaussianRef.

pub fn to_spz( &self, header: &SpzGaussiansHeader, options: &GaussianToSpzOptions, ) -> SpzGaussian

Convert to SpzGaussian.

User usually don’t need to call this directly due to the overhead of constructing a valid SpzGaussiansHeader. Instead, use one of the following methods to convert a collection of Gaussian to SpzGaussians properly: