PlyGaussianPod

Struct PlyGaussianPod 

#[repr(C)]
pub struct PlyGaussianPod { pub pos: [f32; 3], pub normal: [f32; 3], pub color: [f32; 3], pub sh: [f32; 45], pub alpha: f32, pub scale: [f32; 3], pub rot: [f32; 4], }
The POD representation of Gaussian in PLY format.

Fields are stored as arrays because using glam types would add padding according to C alignment rules.

Fields

pos: [f32; 3]normal: [f32; 3]color: [f32; 3]sh: [f32; 45]alpha: f32scale: [f32; 3]rot: [f32; 4]

Implementations

Source

impl PlyGaussianPod

pub fn set_value(&mut self, name: &str, value: f32)

Set the value of a property by name.